Line class

Constructors

Line(double a, double b, double c)
const

Properties

a double
final
angle double
no setter
b double
final
c double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

intersections(Line otherLine) List<Vector2>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromPoints(Vector2 p1, Vector2 p2) Line