LineSegment class

Constructors

LineSegment(Vector2 from, Vector2 to)
LineSegment.zero()
factory

Properties

from Vector2
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to Vector2
final

Methods

containsPoint(Vector2 point, {double epsilon = 0.000001}) bool
crossed(LineSegment otherSegment) bool
intersections(LineSegment otherSegment) List<Vector2>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pointsAt(Line line) bool
toLine() Line
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited