PointerHoverInfo class
- Inheritance
-
- Object
- BaseInfo<
PointerHoverEvent> - PositionInfo<
PointerHoverEvent> - PointerHoverInfo
- Mixed-in types
Constructors
- PointerHoverInfo.fromDetails(Stage stage, PointerHoverEvent raw)
Properties
- handled ↔ bool
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- position → Vector2
-
finalinherited
- raw → PointerHoverEvent
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited