ActorMember class abstract

Implementers

Constructors

ActorMember()

Properties

anchor Anchor
no setter
angle double
no setter
hashCode int
The hash code for this object.
no setterinherited
position Vector2
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale Vector2
no setter
size Vector2
no setter
skew Vector2
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited