Anchor class

Annotations

Constructors

Anchor(double x, double y)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
final
y double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

bottomCenter → const Anchor
bottomLeft → const Anchor
bottomRight → const Anchor
center → const Anchor
centerLeft → const Anchor
centerRight → const Anchor
topCenter → const Anchor
topLeft → const Anchor
topRight → const Anchor