test/close_to_vector library

Functions

closeToVector(num x, num y, {double epsilon = 1e-15}) Matcher
Returns a matcher which checks if the argument is a vector within distance epsilon of point (x, y). For example: