RectPoints class

Implemented types

Constructors

RectPoints({required Vector2 topLeft, required Vector2 topRight, required Vector2 bottomLeft, required Vector2 bottomRight, Anchor anchor = Anchor.center})
RectPoints.fromActor(Actor actor)

Properties

anchor Anchor
getter/setter pairoverride-getter
angle double
no setteroverride
bottomLeft Vector2
getter/setter pair
bottomRight Vector2
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
offset Vector2
no setter
position Vector2
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale Vector2
final
size Vector2
no setteroverride
skew Vector2
no setteroverride
topLeft Vector2
getter/setter pair
topRight Vector2
getter/setter pair
transform MatrixTransform
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateAnchor(Anchor anchor) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited