MatrixTransform class
Constructors
- MatrixTransform({double? angle, Vector2? offset, Vector2? scale, Vector2? skew, Vector2? position})
- MatrixTransform.copy(MatrixTransform other)
-
factory
Properties
- angle ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- matrix → Matrix4
-
no setter
- offset ↔ Vector2
-
getter/setter pair
- position ↔ Vector2
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale ↔ Vector2
-
getter/setter pair
- skew ↔ Vector2
-
getter/setter pair
Methods
-
clone(
) → MatrixTransform -
flip(
) → void -
flipHorizontally(
) → void -
flipVertically(
) → void -
globalToLocal(
Vector2 point) → Vector2 -
localToGlobal(
Vector2 point) → Vector2 -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setOffsetBySizeAndAnchor(
Vector2 size, Anchor anchor) → void -
toRect(
Vector2 size, [Vector2 projector(Vector2 point)?]) → Rect -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited